# larcv-viewer

[![Documentation Status](https://readthedocs.org/projects/larcv-viewer/badge/?version=latest)](https://larcv-viewer.readthedocs.io/en/latest/?badge=latest)

Graphical interface for the LArCV2 data files.  Compatible with python2/3, requires larcv2 and PyQt4/5 as well as numpy, opengl, and pyqtgraph.
